@@ -135,15 +135,16 @@ module IAIConvert
     pd.Series(convert_to_py(col), dtype=dtype)
   end
   function convert_to_py(o::AbstractVector)
-    missing_inds = findall(ismissing, o)
-    if !isempty(missing_inds)
-      o[missing_inds] .= NaN
+    if nonmissingtype(eltype(o)) <: IAI.IAIBase.MixedDatum
+      vals = convert_to_py(Vector{Any}(IAI.undo_mixed_data(o)))
+      iai.MixedData(vals, ordinal_levels=IAI.IAIBase.levels_ordinal(o))
+    else
+      missing_inds = findall(ismissing, o)
+      if !isempty(missing_inds)
+        o[missing_inds] .= NaN
+      end
+      o
     end
-    o
-  end
-  function convert_to_py(o::AbstractVector{<:IAI.IAIBase.MixedDatum})
-    vals = convert_to_py(Vector{Any}(IAI.undo_mixed_data(o)))
-    iai.MixedData(vals, ordinal_levels=IAI.IAIBase.levels_ordinal(o))
   end
   function convert_to_py(o::SubArray)
     convert_to_py(getindex(parent(o), o.indices...))
