@@ -15,7 +15,7 @@ class RandomForestClassifier(RandomForestLearner, ClassificationLearner):
 
     Examples
     --------
-    >>> RandomForestClassifier(**kwargs)
+    >>> iai.RandomForestClassifier(**kwargs)
 
     Parameters
     ----------
@@ -40,7 +40,7 @@ class RandomForestRegressor(RandomForestLearner, RegressionLearner):
 
     Examples
     --------
-    >>> RandomForestRegressor(**kwargs)
+    >>> iai.RandomForestRegressor(**kwargs)
 
     Parameters
     ----------
@@ -68,7 +68,7 @@ class XGBoostLearner(Learner):
 
         Examples
         --------
-        >>> obj.write_booster(filename)
+        >>> lnr.write_booster(filename)
 
         Compatibility
         -------------
@@ -86,7 +86,7 @@ class XGBoostClassifier(XGBoostLearner, ClassificationLearner):
 
     Examples
     --------
-    >>> XGBoostClassifier(**kwargs)
+    >>> iai.XGBoostClassifier(**kwargs)
 
     Parameters
     ----------
@@ -111,7 +111,7 @@ class XGBoostRegressor(XGBoostLearner, RegressionLearner):
 
     Examples
     --------
-    >>> XGBoostRegressor(**kwargs)
+    >>> iai.XGBoostRegressor(**kwargs)
 
     Parameters
     ----------
@@ -208,7 +208,7 @@ class GLMNetCVRegressor(GLMNetLearner, RegressionLearner):
 
     Examples
     --------
-    >>> GLMNetCVRegressor(**kwargs)
+    >>> iai.GLMNetCVRegressor(**kwargs)
 
     Parameters
     ----------
