@@ -13,7 +13,7 @@ def split_data(*args, **kwargs):
 
     Examples
     --------
-    >>> split_data(task, X, *y, **kwargs)
+    >>> iai.split_data(task, X, *y, **kwargs)
     """
     return _IAI.split_data_convert(*args, **kwargs)
 
@@ -26,7 +26,7 @@ def set_rich_output_param(*args, **kwargs):
 
     Examples
     --------
-    >>> set_rich_output_param(key, value)
+    >>> iai.set_rich_output_param(key, value)
     """
     return _IAI.set_rich_output_param_convert(*args, **kwargs)
 
@@ -39,7 +39,7 @@ def get_rich_output_params(*args, **kwargs):
 
     Examples
     --------
-    >>> get_rich_output_params()
+    >>> iai.get_rich_output_params()
     """
     return _IAI.get_rich_output_params_convert(*args, **kwargs)
 
@@ -52,7 +52,7 @@ def delete_rich_output_param(*args, **kwargs):
 
     Examples
     --------
-    >>> delete_rich_output_param(key)
+    >>> iai.delete_rich_output_param(key)
     """
     return _IAI.delete_rich_output_param_convert(*args, **kwargs)
 
@@ -65,7 +65,7 @@ def read_json(filename):
 
     Examples
     --------
-    >>> read_json(filename)
+    >>> iai.read_json(filename)
     """
 
     jl_obj = _IAI.read_json_convert(filename)
@@ -130,7 +130,7 @@ class Learner():
 
         Examples
         --------
-        >>> obj.write_json(filename, **kwargs)
+        >>> lnr.write_json(filename, **kwargs)
         """
         if isinstance(self, GridSearch):
             _requires_iai_version("1.1.0", "write_json (for GridSearch)")
@@ -391,7 +391,7 @@ class GridSearch(Learner):
 
     Examples
     --------
-    >>> GridSearch(lnr, params)
+    >>> iai.GridSearch(lnr, params)
     """
     def __init__(self, lnr, *args, **kwargs):
         if not isinstance(lnr, Learner):
@@ -492,16 +492,57 @@ class GridSearch(Learner):
         return _IAI.get_best_params_convert(self._jl_obj)
 
     def get_grid_results(self):
+        """This method was deprecated and renamed to get_grid_result_summary in
+        interpretableai 2.4.0. This is for consistency with the IAI v2.2.0
+        Julia release.
+        """
+        _warnings.warn(
+            "'get_grid_results' is deprecated, use 'get_grid_result_summary'",
+            FutureWarning
+        )
+        return self.get_grid_result_summary()
+
+    def get_grid_result_summary(self):
         """Return a summary of the results from the grid search.
 
         Julia Equivalent:
-        `IAI.get_grid_results <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_grid_results>`
+        `IAI.get_grid_result_summary <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_grid_result_summary>`
 
         Examples
         --------
-        >>> grid.get_grid_results()
+        >>> grid.get_grid_result_summary()
         """
-        return _IAI.get_grid_results_convert(self._jl_obj)
+        if _iai_version_less_than("2.2.0"):
+            return _IAI.get_grid_results_convert(self._jl_obj)
+        else:
+            return _IAI.get_grid_result_summary_convert(self._jl_obj)
+
+    def get_grid_result_details(self):
+        """Return a `list` of `dict`s detailing the results of the grid search.
+
+        Julia Equivalent:
+        `IAI.get_grid_result_details <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_grid_result_details>`
+
+        Examples
+        --------
+        >>> grid.get_grid_result_details()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_grid_result_details")
+        details = _IAI.get_grid_result_details_convert(self._jl_obj)
+
+        # Convert all Julia learners in the grid to Python equivalents
+        for d in details:
+            for f in d["fold_results"]:
+                jl_obj = f["learner"]
+                lnr = _get_learner_type(jl_obj)()
+                Learner.__init__(lnr, jl_obj)
+                f["learner"] = lnr
+
+        return details
 
     def fit_cv(self, *args, **kwargs):
         """Fit a grid with data `X` and `y` using k-fold cross-validation.
@@ -594,14 +635,14 @@ class ROCCurve():
     `ROCCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#ROCCurve>`
     using trained `lnr` on the features `X` and labels `y`:
 
-    >>> ROCCurve(lnr, X, y)
+    >>> iai.ROCCurve(lnr, X, y)
 
     Construct an
     `ROCCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#ROCCurve>`
     using predicted probabilities `probs` and true labels `y`, with
     probabilities indicating chance of predicting `positive_label`:
 
-    >>> ROCCurve(probs, y, positive_label=positive_label)
+    >>> iai.ROCCurve(probs, y, positive_label=positive_label)
     """
     def __init__(self, *args, **kwargs):
         # Check if grid or learner was passed as first arg
